==> zio-aws-s3_2.12-6.20.78.3-sources.jar: zio/aws/s3/model/ReplicationTimeValue.scala <==
package zio.aws.s3.model
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.s3.model.primitives.Minutes
import java.lang.Integer
import scala.jdk.CollectionConverters._
final case class ReplicationTimeValue(
    minutes: Optional[Minutes] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.s3.model.ReplicationTimeValue = {
    import ReplicationTimeValue.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.s3.model.ReplicationTimeValue
      .builder()
      .optionallyWith(minutes.map(value => Minutes.unwrap(value): Integer))(
        _.minutes
      )
      .build()
  }
  def asReadOnly: zio.aws.s3.model.ReplicationTimeValue.ReadOnly =
    zio.aws.s3.model.ReplicationTimeValue.wrap(buildAwsValue())
}
object ReplicationTimeValue {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.s3.model.ReplicationTimeValue
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.s3.model.ReplicationTimeValue =
      zio.aws.s3.model.ReplicationTimeValue(minutes.map(value => value))
    def minutes: Optional[Minutes]
    def getMinutes: ZIO[Any, AwsError, Minutes] =
      AwsError.unwrapOptionField("minutes", minutes)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.s3.model.ReplicationTimeValue
  ) extends zio.aws.s3.model.ReplicationTimeValue.ReadOnly {
    override val minutes: Optional[Minutes] = zio.aws.core.internal
      .optionalFromNullable(impl.minutes())
      .map(value => zio.aws.s3.model.primitives.Minutes(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.s3.model.ReplicationTimeValue
  ): zio.aws.s3.model.ReplicationTimeValue.ReadOnly = new Wrapper(impl)
}

==> zio-aws-s3_3-5.17.158.4-sources.jar: zio/aws/s3/model/ReplicationTimeValue.scala <==
package zio.aws.s3.model
import java.lang.Integer
import zio.aws.s3.model.primitives.Minutes
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class ReplicationTimeValue(minutes: Option[Minutes] = None) {
  def buildAwsValue()
      : software.amazon.awssdk.services.s3.model.ReplicationTimeValue = {
    import ReplicationTimeValue.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.s3.model.ReplicationTimeValue
      .builder()
      .optionallyWith(minutes.map(value => Minutes.unwrap(value): Integer))(
        _.minutes
      )
      .build()
  }
  def asReadOnly: zio.aws.s3.model.ReplicationTimeValue.ReadOnly =
    zio.aws.s3.model.ReplicationTimeValue.wrap(buildAwsValue())
}
object ReplicationTimeValue {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.s3.model.ReplicationTimeValue
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.s3.model.ReplicationTimeValue =
      zio.aws.s3.model.ReplicationTimeValue(minutes.map(value => value))
    def minutes: Option[Minutes]
    def getMinutes: ZIO[Any, AwsError, Minutes] =
      AwsError.unwrapOptionField("minutes", minutes)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.s3.model.ReplicationTimeValue
  ) extends zio.aws.s3.model.ReplicationTimeValue.ReadOnly {
    override val minutes: Option[Minutes] = scala
      .Option(impl.minutes())
      .map(value => zio.aws.s3.model.primitives.Minutes(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.s3.model.ReplicationTimeValue
  ): zio.aws.s3.model.ReplicationTimeValue.ReadOnly = new Wrapper(impl)
}
